package com.goldenwater.slaj.ttsa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.ttsa.mapper.BisTtsaCertChaCompMapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertChaComp;
import com.goldenwater.slaj.ttsa.service.IBisTtsaCertChaCompService;

@Service
public class BisTtsaCertChaCompServiceImpl implements IBisTtsaCertChaCompService {
    @Autowired
    private BisTtsaCertChaCompMapper bisTtsaCertChaCompMapper;

    @Override
    public BisTtsaCertChaComp selectBisTtsaCertChaCompByGuid(String guid) {
        return bisTtsaCertChaCompMapper.selectBisTtsaCertChaCompByGuid(guid);
    }

    @Override
    public List<BisTtsaCertChaComp> selectBisTtsaCertChaCompList(BisTtsaCertChaComp bisTtsaCertChaComp) {
        return bisTtsaCertChaCompMapper.selectBisTtsaCertChaCompList(bisTtsaCertChaComp);
    }

    @Override
    public int insertBisTtsaCertChaComp(BisTtsaCertChaComp bisTtsaCertChaComp) {
        return bisTtsaCertChaCompMapper.insertBisTtsaCertChaComp(bisTtsaCertChaComp);
    }

    @Override
    public int updateBisTtsaCertChaComp(BisTtsaCertChaComp bisTtsaCertChaComp) {
        return bisTtsaCertChaCompMapper.updateBisTtsaCertChaComp(bisTtsaCertChaComp);
    }

    @Override
    public int deleteBisTtsaCertChaCompByGuid(String guid) {
        return bisTtsaCertChaCompMapper.deleteBisTtsaCertChaCompByGuid(guid);
    }

    @Override
    public int deleteBisTtsaCertChaCompByGuids(String[] guids) {
        return bisTtsaCertChaCompMapper.deleteBisTtsaCertChaCompByGuids(guids);
    }
}
